@@ -26,7 +26,7 @@ class Module
     props = props.map { |p| p.to_s }
 
     path = name.gsub(/::/, "/")
-    yaml_tag "!#{Redwood::YAML_DOMAIN},#{Redwood::YAML_DATE}/#{path}"
+    yaml_tag "tag:#{Redwood::YAML_DOMAIN},#{Redwood::YAML_DATE}/#{path}"
 
     define_method :init_with do |coder|
       initialize(*coder.map.values_at(*props))
@@ -38,9 +38,6 @@ class Module
         hash
       end
     end
-
-    # Legacy
-    Psych.load_tags["!#{Redwood::LEGACY_YAML_DOMAIN},#{Redwood::YAML_DATE}/#{path}"] = self
   end
 end
 
@@ -139,10 +136,17 @@ module Redwood
 
   def load_yaml_obj fn, compress=false
     o = if File.exist? fn
-      if compress
-        Zlib::GzipReader.open(fn) { |f| YAML::load f }
+      raw_contents = if compress
+        Zlib::GzipReader.open(fn) { |f| f.read }
       else
-        YAML::load_file fn
+        File::open(fn) { |f| f.read }
+      end
+      ## fix up malformed tag URIs created by earlier versions of sup
+      raw_contents.gsub!(/!supmua.org,2006-10-01\/(\S*)$/) { |m| "!<tag:supmua.org,2006-10-01/#{$1}>" }
+      if YAML.respond_to?(:unsafe_load)  # Ruby 3.1+
+        YAML::unsafe_load raw_contents
+      else
+        YAML::load raw_contents
       end
     end
     if o.is_a?(Array)
@@ -349,7 +353,7 @@ EOM
       name ||= ENV["USER"]
       email = ENV["USER"] + "@" +
         begin
-          Socket.gethostbyname(Socket.gethostname).first
+          Addrinfo.getaddrinfo(Socket.gethostname, 'smtp').first.getnameinfo.first
         rescue SocketError
           Socket.gethostname
         end
