@@ -1,7 +1,7 @@
 module Redwood
 
 class DraftManager
-  include Singleton
+  include Redwood::Singleton
 
   attr_accessor :source
   def initialize dir
@@ -16,14 +16,14 @@ class DraftManager
   def write_draft
     offset = @source.gen_offset
     fn = @source.fn_for_offset offset
-    File.open(fn, "w") { |f| yield f }
+    File.open(fn, "w:UTF-8") { |f| yield f }
     PollManager.poll_from @source
   end
 
   def discard m
     raise ArgumentError, "not a draft: source id #{m.source.id.inspect}, should be #{DraftManager.source_id.inspect} for #{m.id.inspect}" unless m.source.id.to_i == DraftManager.source_id
     Index.delete m.id
-    File.delete @source.fn_for_offset(m.source_info)
+    File.delete @source.fn_for_offset(m.source_info) rescue Errono::ENOENT
     UpdateManager.relay self, :single_message_deleted, m
   end
 end
@@ -32,14 +32,17 @@ class DraftLoader < Source
   attr_accessor :dir
   yaml_properties
 
-  def initialize
-    dir = Redwood::DRAFT_DIR
-    Dir.mkdir dir unless File.exists? dir
+  def initialize dir=Redwood::DRAFT_DIR
+    Dir.mkdir dir unless File.exist? dir
     super DraftManager.source_name, true, false
     @dir = dir
     @cur_offset = 0
   end
 
+  def properly_initialized?
+    !!(@dir && @cur_offset)
+  end
+
   def id; DraftManager.source_id; end
   def to_s; DraftManager.source_name; end
   def uri; DraftManager.source_name; end
@@ -58,8 +61,8 @@ class DraftLoader < Source
   end
 
   def gen_offset
-    i = 0
-    while File.exists? fn_for_offset(i)
+    i = @cur_offset
+    while File.exist? fn_for_offset(i)
       i += 1
     end
     i
@@ -70,8 +73,9 @@ class DraftLoader < Source
   def load_header offset
     File.open(fn_for_offset(offset)) { |f| parse_raw_email_header f }
   end
-  
+
   def load_message offset
+    raise SourceError, "Draft not found" unless File.exist? fn_for_offset(offset)
     File.open fn_for_offset(offset) do |f|
       RMail::Mailbox::MBoxReader.new(f).each_message do |input|
         return RMail::Parser.read(input)
@@ -81,7 +85,7 @@ class DraftLoader < Source
 
   def raw_header offset
     ret = ""
-    File.open fn_for_offset(offset) do |f|
+    File.open(fn_for_offset(offset), "r:UTF-8") do |f|
       until f.eof? || (l = f.gets) =~ /^$/
         ret += l
       end
@@ -90,13 +94,13 @@ class DraftLoader < Source
   end
 
   def each_raw_message_line offset
-    File.open(fn_for_offset(offset)) do |f|
+    File.open(fn_for_offset(offset), "r:UTF-8") do |f|
       yield f.gets until f.eof?
     end
   end
 
   def raw_message offset
-    IO.read(fn_for_offset(offset))
+    IO.read(fn_for_offset(offset), :encoding => "UTF-8")
   end
 
   def start_offset; 0; end
