@@ -1,6 +1,16 @@
+require 'sup/util/ncurses'
+
 module Redwood
 
 class Keymap
+
+  HookManager.register "keybindings", <<EOS
+Add custom keybindings.
+Methods:
+  modes: Hash from mode names to mode classes.
+  global_keymap: The top-level keymap.
+EOS
+
   def initialize
     @map = {}
     @order = []
@@ -9,19 +19,19 @@ class Keymap
 
   def self.keysym_to_keycode k
     case k
-    when :down then Curses::KEY_DOWN
-    when :up then Curses::KEY_UP
-    when :left then Curses::KEY_LEFT
-    when :right then Curses::KEY_RIGHT
-    when :page_down then Curses::KEY_NPAGE
-    when :page_up then Curses::KEY_PPAGE
-    when :backspace then Curses::KEY_BACKSPACE
-    when :home then Curses::KEY_HOME
-    when :end then Curses::KEY_END
+    when :down then Ncurses::KEY_DOWN
+    when :up then Ncurses::KEY_UP
+    when :left then Ncurses::KEY_LEFT
+    when :right then Ncurses::KEY_RIGHT
+    when :page_down then Ncurses::KEY_NPAGE
+    when :page_up then Ncurses::KEY_PPAGE
+    when :backspace then Ncurses::KEY_BACKSPACE
+    when :home then Ncurses::KEY_HOME
+    when :end then Ncurses::KEY_END
     when :ctrl_l then "\f".ord
     when :ctrl_g then "\a".ord
     when :tab then "\t".ord
-    when :enter, :return then 10 #Curses::KEY_ENTER
+    when :enter, :return then 10 #Ncurses::KEY_ENTER
     else
       if k.is_a?(String) && k.length == 1
         k.ord
@@ -46,7 +56,7 @@ class Keymap
     when :tab then "tab"
     when " " then "<space>"
     else
-      Curses::keyname(keysym_to_keycode(k))
+      Ncurses::keyname(keysym_to_keycode(k))
     end
   end
 
@@ -60,18 +70,39 @@ class Keymap
     end
   end
 
+  def delete k
+    kc = Keymap.keysym_to_keycode(k)
+    return unless @map.member? kc
+    entry = @map.delete kc
+    keys = entry[2]
+    keys.delete k
+    @order.delete entry if keys.empty?
+  end
+
+  def add! action, help, *keys
+    keys.each { |k| delete k }
+    add action, help, *keys
+  end
+
   def add_multi prompt, key
-    submap = Keymap.new
-    add submap, prompt, key
-    yield submap
+    kc = Keymap.keysym_to_keycode(key)
+    if @map.member? kc
+      action = @map[kc].first
+      raise "existing action is not a keymap" unless action.is_a?(Keymap)
+      yield action
+    else
+      submap = Keymap.new
+      add submap, prompt, key
+      yield submap
+    end
   end
 
   def action_for kc
-    action, help, keys = @map[kc]
+    action, help, _keys = @map[kc.code]
     [action, help]
   end
 
-  def has_key? k; @map[k] end
+  def has_key? k; @map[k.code] end
 
   def keysyms; @map.values.map { |action, help, keys| keys }.flatten; end
 
@@ -95,6 +126,15 @@ class Keymap
     llen = lines.max_of { |a, b| a.length }
     lines.map { |a, b| sprintf " %#{llen}s : %s", a, b }.join("\n")
   end
+
+  def self.run_hook global_keymap
+    modes = Hash[Mode.keymaps.map { |klass,keymap| [Mode.make_name(klass.name),klass] }]
+    locals = {
+      :modes => modes,
+      :global_keymap => global_keymap,
+    }
+    HookManager.run 'keybindings', locals
+  end
 end
 
 end
