@@ -1,5 +1,6 @@
 require 'uri'
 require 'set'
+require 'time'
 
 module Redwood
 
@@ -85,7 +86,7 @@ class MBox < Source
       begin
         ## don't use RMail::Mailbox::MBoxReader because it doesn't properly ignore
         ## "From" at the start of a message body line.
-        string = ""
+        string = +""
         until @f.eof? || MBox::is_break_line?(l = @f.gets)
           string << l
         end
@@ -97,7 +98,7 @@ class MBox < Source
   end
 
   def raw_header offset
-    ret = ""
+    ret = +""
     @mutex.synchronize do
       ensure_open
       @f.seek offset
@@ -109,9 +110,7 @@ class MBox < Source
   end
 
   def raw_message offset
-    ret = ""
-    each_raw_message_line(offset) { |l| ret << l }
-    ret
+    enum_for(:each_raw_message_line, offset).reduce(:+)
   end
 
   def store_message date, from_email, &block
@@ -137,6 +136,26 @@ class MBox < Source
     end
   end
 
+  def fallback_date_for_message offset
+    ## This is a bit awkward... We treat the From line as a delimiter,
+    ## not part of the message. So the offset is pointing *after* the
+    ## From line for the desired message. With a bit of effort we can
+    ## scan backwards to find its From line and extract a date from it.
+    buf = @mutex.synchronize do
+      ensure_open
+      start = offset
+      loop do
+        start = (start - 200).clamp 0, 2**64
+        @f.seek start
+        buf = @f.read (offset - start)
+        break buf if buf.include? ?\n or start == 0
+      end
+    end
+    BREAK_RE.match buf.lines.last do |m|
+      Time.strptime m[1], "%a %b %d %H:%M:%S %Y"
+    end
+  end
+
   def default_labels
     [:inbox, :unread]
   end
@@ -179,8 +198,7 @@ class MBox < Source
     l =~ BREAK_RE or return false
     time = $1
     begin
-      ## hack -- make Time.parse fail when trying to substitute values from Time.now
-      Time.parse time, Time.at(0)
+      Time.strptime time, "%a %b %d %H:%M:%S %Y"
       true
     rescue NoMethodError, ArgumentError
       warn "found invalid date in potential mbox split line, not splitting: #{l.inspect}"
