@@ -103,16 +103,10 @@ class Message
     when Time
       date
     when String
-      begin
-        Time.parse date
-      rescue ArgumentError
-        #debug "faking mangled date header for #{@id} (orig #{header['date'].inspect} gave error: #{e.message})"
-        Time.now
-      end
-    else
-      #debug "faking non-existent date header for #{@id}"
-      Time.now
+      Time.rfc2822 date rescue nil
     end
+    @date = location.fallback_date if @date.nil?
+    @date = Time.utc 1970, 1, 1 if @date.nil?
 
     subj = header["subject"]
     subj = subj ? subj.fix_encoding! : nil
@@ -466,6 +460,11 @@ private
     end
   end
 
+  def has_embedded_message? m
+    return false unless m.header.content_type
+    %w(message/rfc822 message/global).include? m.header.content_type.downcase
+  end
+
   ## takes a RMail::Message, breaks it into Chunk:: classes.
   def message_to_chunks m, encrypted=false, sibling_types=[]
     if m.multipart?
@@ -483,7 +482,7 @@ private
       end
 
       chunks
-    elsif m.header.content_type && m.header.content_type.downcase == "message/rfc822"
+    elsif has_embedded_message? m
       encoding = m.header["Content-Transfer-Encoding"]
       if m.body
         body =
@@ -808,6 +807,10 @@ class Location
     source.load_message info
   end
 
+  def fallback_date
+    source.fallback_date_for_message info
+  end
+
   def valid?
     source.valid? info
   end
