@@ -1,8 +1,10 @@
+require 'sup/util/ncurses'
+
 module Redwood
 
 ## a fully-functional text field supporting completions, expansions,
 ## history--everything!
-## 
+##
 ## writing this fucking sucked. if you thought ncurses was some 1970s
 ## before-people-knew-how-to-program bullshit, wait till you see
 ## ncurses forms.
@@ -16,6 +18,8 @@ module Redwood
 ## in sup, completion support is implemented through BufferManager#ask
 ## and CompletionMode.
 class TextField
+  include Ncurses::Form::DriverHelpers
+
   def initialize
     @i = nil
     @history = []
@@ -33,7 +37,11 @@ class TextField
     @w, @y, @x, @width = window, y, x, width
     @question = question
     @completion_block = block
-    @field = Ncurses::Form.new_field 1, @width - question.length, @y, @x + question.length, 256, 0
+    @field = Ncurses::Form.new_field 1, @width - question.length, @y, @x + question.length, 0, 0
+    if @field.respond_to? :opts_off
+      @field.opts_off Ncurses::Form::O_STATIC
+      @field.opts_off Ncurses::Form::O_BLANK
+    end
     @form = Ncurses::Form.new_form [@field]
     @value = default || ''
     Ncurses::Form.post_form @form
@@ -44,8 +52,8 @@ class TextField
     @w.attrset Colormap.color_for(:none)
     @w.mvaddstr @y, 0, @question
     Ncurses.curs_set 1
-    Ncurses::Form.form_driver @form, Ncurses::Form::REQ_END_FIELD
-    Ncurses::Form.form_driver @form, Ncurses::Form::REQ_NEXT_CHAR if @value && @value =~ / $/ # fucking RETARDED
+    form_driver_key Ncurses::Form::REQ_END_FIELD
+    form_driver_key Ncurses::Form::REQ_NEXT_CHAR if @value && @value =~ / $/ # fucking RETARDED
   end
 
   def deactivate
@@ -59,10 +67,11 @@ class TextField
 
   def handle_input c
     ## short-circuit exit paths
-    case c
+    case c.code
     when Ncurses::KEY_ENTER # submit!
       @value = get_cursed_value
       @history.push @value unless @value =~ /^\s*$/
+      @i = @history.size
       return false
     when Ncurses::KEY_CANCEL # cancel
       @value = nil
@@ -92,48 +101,65 @@ class TextField
     reset_completion_state
     @value = nil
 
-    d =
-      case c
+    # ctrl_c: control char
+    ctrl_c =
+      case c.keycode # only test for keycodes
       when Ncurses::KEY_LEFT
         Ncurses::Form::REQ_PREV_CHAR
       when Ncurses::KEY_RIGHT
         Ncurses::Form::REQ_NEXT_CHAR
       when Ncurses::KEY_DC
         Ncurses::Form::REQ_DEL_CHAR
-      when Ncurses::KEY_BACKSPACE, 127 # 127 is also a backspace keysym
+      when Ncurses::KEY_BACKSPACE
         Ncurses::Form::REQ_DEL_PREV
-      when ?\C-a
+      when Ncurses::KEY_HOME
         nop
         Ncurses::Form::REQ_BEG_FIELD
-      when ?\C-e
+      when Ncurses::KEY_END
         Ncurses::Form::REQ_END_FIELD
-      when ?\C-k
-        Ncurses::Form::REQ_CLR_EOF
-      when ?\C-u
-        set_cursed_value cursed_value_after_point
-        Ncurses::Form.form_driver @form, Ncurses::Form::REQ_END_FIELD
-        nop
-        Ncurses::Form::REQ_BEG_FIELD
-      when ?\C-w
-        Ncurses::Form.form_driver @form, Ncurses::Form::REQ_PREV_CHAR
-        Ncurses::Form.form_driver @form, Ncurses::Form::REQ_DEL_WORD
       when Ncurses::KEY_UP, Ncurses::KEY_DOWN
-        unless @history.empty?
-          value = get_cursed_value
-          @i ||= @history.size
+        unless !@i || @history.empty?
           #debug "history before #{@history.inspect}"
-          @history[@i] = value #unless value =~ /^\s*$/
-          @i = (@i + (c == Ncurses::KEY_UP ? -1 : 1)) % @history.size
-          @value = @history[@i]
+          @i = @i + (c.is_keycode?(Ncurses::KEY_UP) ? -1 : 1)
+          @i = 0 if @i < 0
+          @i = @history.size if @i > @history.size
+          @value = @history[@i] || ''
           #debug "history after #{@history.inspect}"
           set_cursed_value @value
           Ncurses::Form::REQ_END_FIELD
         end
       else
-        c
+        # return other keycode or nil if it's not a keycode
+        c.dumb? ? nil : c.keycode
       end
 
-    Ncurses::Form.form_driver @form, d if d
+    # handle keysyms
+    # ctrl_c: control char
+    ctrl_c = case c
+      when ?\177                          # backspace (octal)
+        Ncurses::Form::REQ_DEL_PREV
+      when ?\C-a                          # home
+        nop
+        Ncurses::Form::REQ_BEG_FIELD
+      when ?\C-e                          # end keysym
+        Ncurses::Form::REQ_END_FIELD
+      when ?\C-k
+        Ncurses::Form::REQ_CLR_EOF
+      when ?\C-u
+        set_cursed_value cursed_value_after_point
+        form_driver_key Ncurses::Form::REQ_END_FIELD
+        nop
+        Ncurses::Form::REQ_BEG_FIELD
+      when ?\C-w
+        while action = remove_extra_space
+          form_driver_key action
+        end
+        form_driver_key Ncurses::Form::REQ_PREV_CHAR
+        form_driver_key Ncurses::Form::REQ_DEL_WORD
+      end if ctrl_c.nil?
+
+    c.replace(ctrl_c).keycode! if ctrl_c  # no effect for dumb CharCode
+    form_driver c if c.present?
     true
   end
 
@@ -151,7 +177,7 @@ private
     return nil unless @field
 
     x = Ncurses.curx
-    Ncurses::Form.form_driver @form, Ncurses::Form::REQ_VALIDATION
+    form_driver_key Ncurses::Form::REQ_VALIDATION
     v = @field.field_buffer(0).gsub(/^\s+|\s+$/, "")
 
     ## cursor <= end of text
@@ -160,9 +186,54 @@ private
     else # trailing spaces
       v + (" " * (x - @question.length - v.length))
     end
+
+    # ncurses returns a ASCII-8BIT (binary) string, which
+    # bytes presumably are of current charset encoding. we force_encoding
+    # so that the char representation / string is tagged will be the
+    # system locale and also hopefully the terminal/input encoding. an
+    # incorrectly configured terminal encoding (not matching the system
+    # encoding) will produce erronous results, but will also do that for
+    # a lot of other programs since it is impossible to detect which is
+    # which and what encoding the inputted byte chars are supposed to have.
+    v.force_encoding($encoding).fix_encoding!
+  end
+
+  def remove_extra_space
+    return nil unless @field
+
+    form_driver_key Ncurses::Form::REQ_VALIDATION
+    x = Ncurses.curx
+    v = @field.field_buffer(0).gsub(/^\s+|\s+$/, "")
+    v_index = x - @question.length
+
+    # at start of line
+    if v_index < 1
+      nil
+    ## cursor <= end of text
+    elsif v_index < v.length
+      # is the character before the cursor a space?
+      if v[v_index-1] == ?\s
+        # if there is a non-space char under cursor then go back
+        if v[v_index] != ?\s
+          Ncurses::Form::REQ_PREV_CHAR
+        # otherwise delete the space
+        else
+          Ncurses::Form::REQ_DEL_PREV
+        end
+      else
+        nil
+      end
+    elsif v_index == v.length
+      # at end of string, with non-space before us
+      nil
+    else
+      # trailing spaces
+      Ncurses::Form::REQ_PREV_CHAR
+    end
   end
 
   def set_cursed_value v
+    v = "" if v.nil?
     @field.set_field_buffer 0, v
   end
 
@@ -174,8 +245,8 @@ private
   ## this is almost certainly unnecessary, but it's the only way
   ## i could get ncurses to remember my form's value
   def nop
-    Ncurses::Form.form_driver @form, " "[0]
-    Ncurses::Form.form_driver @form, Ncurses::Form::REQ_DEL_PREV
+    form_driver_char " "
+    form_driver_key Ncurses::Form::REQ_DEL_PREV
   end
 end
 end
