@@ -344,6 +344,35 @@ class TestMessage < Minitest::Test
     assert_equal("Second line.", chunks[2].lines[1])
   end
 
+  def test_embedded_message_rfc6532
+    source = DummySource.new("sup-test://test_embedded_message_rfc6532")
+    source.messages = [ fixture_path("embedded-message-rfc6532.eml") ]
+
+    sup_message = Message.build_from_source(source, 0)
+
+    chunks = sup_message.load_from_source!
+    assert_equal(3, chunks.length)
+
+    assert_equal("Email with embedded message", sup_message.subj)
+
+    assert(chunks[0].is_a? Redwood::Chunk::Text)
+    assert_equal("Example outer message.", chunks[0].lines[0])
+
+    assert(chunks[1].is_a? Redwood::Chunk::EnclosedMessage)
+    assert_equal(4, chunks[1].lines.length)
+    assert_equal("From: Embed sender <embed@example.com>", chunks[1].lines[0])
+    assert_equal("To: rcpt2 <rcpt2@example.invalid>", chunks[1].lines[1])
+    assert_equal("Date: ", chunks[1].lines[2][0..5])
+    assert_equal(
+      Time.rfc2822("Sun, 12 May 2024 17:34:29 +1000"),
+      Time.rfc2822(chunks[1].lines[2][6..-1])
+    )
+    assert_equal("Subject: Embedded subject line with emoji ✨", chunks[1].lines[3])
+
+    assert(chunks[2].is_a? Redwood::Chunk::Text)
+    assert_equal("Example embedded message, with UTF-8 headers.", chunks[2].lines[0])
+  end
+
   def test_malicious_attachment_names
     source = DummySource.new("sup-test://test_blank_header_lines")
     source.messages = [ fixture_path('malicious-attachment-names.eml') ]
@@ -359,6 +388,19 @@ class TestMessage < Minitest::Test
     fn = chunks[3].safe_filename
     assert_equal(fn, File.basename(fn))
   end
+
+  def test_invalid_date_header
+    fallback_date = Time.utc 2024, 5, 12, 15, 5, 56
+    source = DummySource.new("sup-test://test_invalid_date_header")
+    source.messages = [ fixture_path("invalid-date.eml") ]
+    source.fallback_date = fallback_date
+
+    sup_message = Message.build_from_source(source, 0)
+    sup_message.load_from_source!
+
+    assert_equal(fallback_date, sup_message.date)
+  end
+
   # TODO: test different error cases, malformed messages etc.
 
   # TODO: test different quoting styles, see that they are all divided
